export declare class Boleto {
    private number;
    /**
     * @param {string} number codigo de barras ou linha digitável de boletos bancários ou arrecadação
     */
    constructor(number: string);
    /**
     * Identifica o tipo da numeração informada, se é código de barras, linha digitável ou inválida
     *
     * @return {string} CODIGO DE BARRAS
     * @return {string} LINHA DIGITAVEL
     * @return {string} INVALIDO
     */
    codeType(): "CODIGO DE BARRAS" | "LINHA DIGITAVEL" | "INVALIDO";
    /**
     * Identifica se o tipo do boleto é bancário ou arrecadação.
     * Em caso de arrecação é retornado também o subtipo
     *
     * @return {object} {BANCO, ''}
     * @return {object} {ARRECADACAO, ''}
     * @return {object} {ARRECADACAO, ARRECADACAO_PREFEITURA}
     * @return {object} {ARRECADACAO, CONVENIO_SANEAMENTO}
     * @return {object} {ARRECADACAO, CONVENIO_ENERGIA_ELETRICA_E_GAS}
     * @return {object} {ARRECADACAO, CONVENIO_TELECOMUNICACOES}
     * @return {object} {ARRECADACAO, ARRECADACAO_ORGAOS_GOVERNAMENTAIS}
     * @return {object} {ARRECADACAO, OUTROS}
     * @return {object} {ARRECADACAO, ARRECADACAO_TAXAS_DE_TRANSITO}
     */
    type(): {
        type: string;
        subtype: string;
    };
    /**
     * Retorna a data de vencimento
     */
    expirationDate(): Date;
    /**
     * Verifica se o boleto esta vencido
     *
     * @return {boolean} true | false
     */
    expired(): boolean;
    /**
     * Retorna a quantdade de dias vencidos
     */
    expiredDays(): number | boolean;
    /**
     * Retorna o nome do banco
     */
    banks(): string;
    /**
     * Retorna o valor do boleto
     */
    amount(): number;
    /**
     * Retorna o valor do boleto formatado (BRL)
     */
    prettyAmount(): string | number;
    /**
     * Calcula e retorna o juros do boleto
     *
     * @param {interestValuenumber}  Porcentagem ou valor cobrado.
     * @param {number|boolean} expiredDays  Quantidade de dias vencidos, caso não informe a quantidade
     * ou informe false para este parâmetro, a quantidade de dias vencido é retirado do boleto.
     * @param {boolean} percent Forma de cobrança, por padrão é habilitado como porcentagem
     * caso seja em reais, atribua false
     * @param {boolean} month Informe se o juros é cobrado ao mês ou ao dia, para dia informe false
     *
     */
    interest(interestValue: number, expiredDays: number, percent?: boolean, month?: boolean): number;
    /**
     * Calcula e retorna a multa do boleto
     *
     * @param {number} finesValue Porcentagem ou valor cobrada.
     * @param {boolean} percent Forma de cobrança, por padrão é habilitado como porcentagem
     * caso seja em reais, atribua false
     */
    fines(finesValue: number, percent?: boolean): number;
    /**
     * Verifica se o boleto é valido
     *
     * @return {boolean} true | false
     */
    valid(): boolean;
    /**
     * Retorna um objeto com todas informações do boleto.
     *
     * @return {object | null}
     */
    toJSON(): {
        barcode: string;
        codeType: string;
        type: string;
        expirationDate: Date;
        expired: boolean;
        expiredDays: number | boolean;
        banks: string;
        amount: number;
        prettyAmount: string | number;
        valid: boolean;
    } | null;
}
